#
# spec file for package zypper-lifecycle-plugin
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           zypper-lifecycle-plugin
Url:            https://github.com/SUSE/zypper-lifecycle
Version:        0.6.1601367426.843fe7a
Release:        4.4
Requires:       zypper >= 1.13.10
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  ruby-macros >= 5
BuildRequires:  zypper >= 1.13.10
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd-rpm-macros
%endif
%{?systemd_requires}

Source:         zypper-lifecycle-%{version}.tar.xz
Patch0:	harden_lifecycle-report.service.patch
Summary:        Zypper subcommand for lifecycle information
License:        GPL-2.0
Group:          System/Packages
BuildArch:      noarch

%description
Zypper subcommand for products and packages lifecycle information.

%prep
%autosetup -p1 -n zypper-lifecycle-%{version}

%build

%install
mkdir -p %{buildroot}/usr/lib/zypper/commands %{buildroot}/%{_mandir}/man8
install -m 755 zypper-lifecycle %{buildroot}/usr/lib/zypper/commands/
install -m 644 zypper-lifecycle.8 %{buildroot}/%{_mandir}/man8/
mkdir -p %{buildroot}/var/lib/lifecycle
mkdir -p %{buildroot}/usr/share/lifecycle
install -m 755 lifecycle-report %{buildroot}/usr/share/lifecycle/
mkdir -p %{buildroot}/usr/lib/systemd/system
install -m 644 lifecycle-report.service %{buildroot}%{_unitdir}
install -m 644 lifecycle-report.timer %{buildroot}%{_unitdir}
install -D -m 644 sysconfig.lifecycle-report %{buildroot}%{_fillupdir}/sysconfig.lifecycle-report

%pre
%service_add_pre lifecycle-report.service lifecycle-report.timer

%post
%{fillup_only -n lifecycle-report}
%service_add_post lifecycle-report.service lifecycle-report.timer

%preun
%service_del_preun lifecycle-report.service lifecycle-report.timer

%postun
%service_del_postun lifecycle-report.service lifecycle-report.timer

%files
%defattr(-,root,root,-)
/usr/lib/zypper/commands
/usr/share/lifecycle
/var/lib/lifecycle
%{_mandir}/man8/*
%{_unitdir}/*
%{_fillupdir}/*

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Thu May 12 2022 Fabian Vogt <fvogt@suse.com>
- Drop unconditional supplements on zypper. It's already recommended
  by patterns-base-sw_management, and there only for stable distributions
  and not Tumbleweed.
* Tue Jan 11 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_lifecycle-report.service.patch
* Tue Sep 29 2020 Vladimir Nadvornik <nadvornik@suse.com>
- Version 0.6.1601367426.843fe7a
- Allow wildcard matching (jsc#SLE-14168)
- Implement successor handling (jsc#SLE-16251)
* Fri Aug  7 2020 Vladimir Nadvornik <nadvornik@suse.com>
- Version 0.6.1596796104.87bdab7
- Handle zypper errors (bsc#1174369)
- Fix ruby warning (bsc#1173714)
- Handle all times in UTC (bsc#1143453)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Mar 24 2017 nadvornik@suse.com
- do not show version number by default (fate#322212)
* Wed Mar  8 2017 nadvornik@suse.com
- fixed unhandled exception on empty package list (bsc#1028247#c1)
* Thu Mar  2 2017 nadvornik@suse.com
- version 0.6
- save state and report changes since saved state (fate#322059)
- added systemd timer for periodical reports (fate#322059)
- look for lifecycle data also in /usr (bsc#1014622)
- support also openSUSE vendor (bsc#1014620)
* Mon Sep 26 2016 nadvornik@suse.com
- version 0.5
- consider also codestream in date/days argument (bsc#999537)
- handle missing codestream name (bsc#1000595)
* Tue Sep 13 2016 nadvornik@suse.com
- version 0.4
- handle codestream info (fate#320835)
- clarify help text (bnc#981106)
* Tue Jul 26 2016 nadvornik@suse.com
- version 0.3
- use product eol according to FATE#320699
- adjust output
* Fri May 13 2016 nadvornik@suse.com
- version 0.2
- fixed return value (bsc#979322)
- do not ignore errors on parsing of lifecycle data (bsc#979431)
* Fri May  6 2016 nadvornik@suse.com
- initial version 0.1 (fate#320597)
